#
# spec file for package gensio
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover 6
%global sover_cpp 6
%global libname libgensio6
%global libname_cpp libgensiocpp%{sover_cpp}
%if 0%{?suse_version} > 1500
%bcond_without openipmi
%else
%bcond_with    openipmi
%endif
Name:           gensio
Version:        2.7.5
Release:        1.1
Summary:        Library to abstract stream and packet I/O
# examples/* is licenced under Apache-2.0
License:        Apache-2.0 AND GPL-2.0-only AND LGPL-2.1-only
Group:          Productivity/Networking/Other
URL:            https://github.com/cminyard/gensio
#Git-Clone:     https://github.com/cminyard/gensio.git
Source:         https://github.com/cminyard/gensio/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  lksctp-tools-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(avahi-client)
%if %{with openipmi}
BuildRequires:  pkgconfig(OpenIPMI)
%endif

%description
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types. You
create a gensio object (or a gensio), and you can use that gensio
without having to know too much about what is going on underneath.
You can stack gensio on top of another one to add protocol
funcionality. For instance, you can create a TCP gensio, stack SSL
on top of that, and stack Telnet on top of that. It supports a
number of network I/O and serial ports. gensios that stack on
other gensios are called filters.

%package -n %{libname}
Summary:        Library to abstract stream and packet I/O
Group:          System/Libraries

%description -n %{libname}
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types. You
create a gensio object (or a gensio), and you can use that gensio
without having to know too much about what is going on underneath.
You can stack gensio on top of another one to add protocol
funcionality. For instance, you can create a TCP gensio, stack SSL
on top of that, and stack Telnet on top of that. It supports a
number of network I/O and serial ports. gensios that stack on
other gensios are called filters.

%package -n libgensioosh%{sover}
Summary:        Library to abstract stream and packet I/O
Group:          System/Libraries

%description -n libgensioosh%{sover}
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types - osh support

%package -n libgensiomdns%{sover}
Summary:        Library to abstract stream and packet I/O
Group:          System/Libraries

%description -n libgensiomdns%{sover}
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types - mdns support

%package -n libgensio_python_swig%{sover}
Summary:        Library to abstract stream and packet I/O
Group:          System/Libraries
Provides:       libgensio0:/usr/lib/libgensio_python_swig.so.0.0.0
Obsoletes:      libgensio0 < %{version}

%description -n libgensio_python_swig%{sover}
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types - python support

%package -n %{libname_cpp}
Summary:        Library to abstract stream and packet I/O
Group:          System/Libraries

%description -n %{libname_cpp}
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types. You
create a gensio object (or a gensio), and you can use that gensio
without having to know too much about what is going on underneath.
You can stack gensio on top of another one to add protocol
funcionality. For instance, you can create a TCP gensio, stack SSL
on top of that, and stack Telnet on top of that. It supports a
number of network I/O and serial ports. gensios that stack on
other gensios are called filters.

%package devel
Summary:        Library to abstract stream and packet I/O
Group:          Development/Libraries/C and C++
Requires:       %{libname_cpp} = %{version}
Requires:       %{libname} = %{version}
Requires:       lksctp-tools-devel
Requires:       pkgconfig(avahi-client)
%if %{with openipmi}
Requires:       pkgconfig(OpenIPMI)
%endif

%description devel
This is gensio (pronounced gen'-see-oh), a framework for giving a
consistent view of various stream (and packet) I/O types. You
create a gensio object (or a gensio), and you can use that gensio
without having to know too much about what is going on underneath.
You can stack gensio on top of another one to add protocol
funcionality. For instance, you can create a TCP gensio, stack SSL
on top of that, and stack Telnet on top of that. It supports a
number of network I/O and serial ports. gensios that stack on
other gensios are called filters.

This subpackage contains libraries and header files for developing
applications that want to make use of libgensio.

%package -n python3-gensio
Summary:        Python bindings for libgensio
Group:          System/Libraries

%description -n python3-gensio
Python bindings for libgensio, a library for stream and packet I/O
abscration.

%prep
%setup -q

%build
export CFLAGS="%optflags -fcommon"
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%post -n libgensioosh%{sover} -p /sbin/ldconfig
%postun -n libgensioosh%{sover} -p /sbin/ldconfig
%post -n libgensiomdns%{sover} -p /sbin/ldconfig
%postun -n libgensiomdns%{sover} -p /sbin/ldconfig
%post -n libgensio_python_swig%{sover} -p /sbin/ldconfig
%postun -n libgensio_python_swig%{sover} -p /sbin/ldconfig
%post -n %{libname_cpp} -p /sbin/ldconfig
%postun -n %{libname_cpp} -p /sbin/ldconfig

%files
%license COPYING COPYING.LIB
%doc AUTHORS ChangeLog NEWS README.rst
%{_bindir}/gensiot
%{_bindir}/gmdns
%{_bindir}/greflector
%{_bindir}/gsound
%{_bindir}/gtlssh
%{_bindir}/gtlssh-keygen
%{_bindir}/gtlssync
%{_mandir}/man1/gensiot.1%{?ext_man}
%{_mandir}/man1/gmdns.1%{?ext_man}
%{_mandir}/man1/greflector.1%{?ext_man}
%{_mandir}/man1/gsound.1%{?ext_man}
%{_mandir}/man1/gtlssh-keygen.1%{?ext_man}
%{_mandir}/man1/gtlssh.1%{?ext_man}
%{_mandir}/man1/gtlssync.1%{?ext_man}
%{_mandir}/man5/gensio.5%{?ext_man}
%{_mandir}/man5/sergensio.5%{?ext_man}

%files -n %{libname}
%{_libdir}/libgensio.so.%{sover_cpp}*
%dir %{_libexecdir}/gensio
%{_libexecdir}/gensio/%{version}

%files -n libgensioosh%{sover}
%{_libdir}/libgensioosh.so.%{sover}*
%{_libdir}/libgensiooshcpp.so.%{sover}*

%files -n libgensiomdns%{sover}
%{_libdir}/libgensiomdns.so.%{sover}*
%{_libdir}/libgensiomdnscpp.so.%{sover}*

%files -n libgensio_python_swig%{sover}
%{_libdir}/libgensio_python_swig.so.%{sover}*

%files -n %{libname_cpp}
%{_libdir}/libgensiocpp.so.%{sover_cpp}*

%files devel
%{_includedir}/gensio/
%{_libdir}/libgensio*.so
%{_libdir}/pkgconfig/libgensio*.pc
%{_mandir}/man3/gensio_*3%{?ext_man}
%{_mandir}/man3/sergensio_*3%{?ext_man}
%{_mandir}/man3/str_to_gensio*.3%{?ext_man}

%files -n python3-gensio
%{python3_sitelib}/*

%changelog
* Tue Aug 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to 2.7.5
  * https://github.com/cminyard/gensio/compare/v2.6.1...v2.7.5
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.6.4:
  * https://github.com/cminyard/gensio/compare/v2.5.4...v2.6.1
  * The internal structure has been reworked so that gensios are dynamically loaded
    by default and can be individually selected at build time. The library itself
    was getting too many dependencies, so these dependencies are pushed to the
    individally loaded gensios. There should be no difference from the user's point
    of view; gensios go into libexec and get loaded on demand. And you can write
    your own and stick them in this directory and it will pick them up.
  * The os interface and mdns code has been put into their own libraries. There
    were circular dependencies, and mdns brings a boatload of other libraries. They
    really aren't gensios, they are gensio support, so they needed to be in their
    own library anyway. This make the gensio library just about gensios. But it
    will change the way you have to link against it if you are using mdns.
  * The sound gensio is now no longer experimental, I'd say it's beta quality now.
  * An AFSK modem gensio has been added. It sits on top of the sound gensio and
    implements the 1200 baud modem used for AX.25 in ham radio.  pty and stdio have
    a change in the way euid and uid setting work. There wasn't a security issue,
    per se, but the way it was before didn't work on BSD. This makes the usage more
    standard.
- add splitprovides/obsoletes
* Wed Sep  7 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.4
  * Ratelimit - limit the data throughput on the write side of
    the gensio stack. This is useful if you have a slow device on
    a serial port that doesn't have flow control.
  * Sound - Yes, you can access sound on Linux
  * Fixed multiple bugs
  * This release adds a workaround for non-compliant AX.25 stacks.
  * It also fixes a long-standing bug with blocking I/O; in
    certain situations it can crash. This will not affect
    ser2net, but if you are using blocking I/O, it could affect you.
* Fri May 20 2022 Martin Hauke <mardnh@gmx.de>
- Udpate to version 2.4.1
  * Added support for the AX25 Amateur Radio packet protocol
  * Rewritten the C++ interface
* Thu Feb 24 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.6
  * Another bugfix release
* Sat Nov 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.5
  * Bugfix release
* Thu Nov 18 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.4
  * Bugfix release
- Update to version 2.3.3
  * The major feature part of this is gensiot is rewritten to
    support a server mode, which allows it to continue to accept
    connections after a connection comes in. As part of this, it
    supports multiple threads, pidfiles, and output to syslog.
    This is useful as a stripped down ser2net, and also for
    creating a forwarding application, letting you convert a
    non-ssl connection to an ssl on, or receive ssl connections
    and forward them to a local application that doesn't support
    ssl.
  * The oomtests are getting better.
* Sun Nov  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  * Bugfix release
* Fri Oct 22 2021 Martin Hauke <mardnh@gmx.de>
- We build gensio with support for SCTP, MDNS and OpenIPMI; let's
  adjust the requirements for the -devel package accordingly.
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.1
  * C++ support. The interface was already OO, this is a mapping
    into C++. It's light, but not much was required.
  * Built-in TCL and glib OS handlers were added.
  * 2-factor authentication support is built-in to the certauth
    protocol.
  * Support for elliptical keys was added to certauth.
* Mon Aug 23 2021 Martin Hauke <mardnh@gmx.de>
- Udpate to version 2.2.9
  * A user noticed that doing a "send break" operation on a telnet
    connection would crash ser2net. It would only happen if
    rfc2217 was not enabled. I've uploaded a new version to fix the
    issue.
- Udpate to version 2.2.8
  * This release adds 2-factor authentication support to gtlssh.
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.7
  * Fix: multiple connections to UDP sockets not work correctly.
- Update to version 2.2.6
  * Mostly small bug fixes.
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.5
  * Mostly small bug fixes.
* Sat Feb  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.4
  * Minor bug fixes, including a long standing issue with UDP.
* Sun Jan 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.2
  * fixes a compile error if openipmi is not installed
* Wed Dec  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.1
  * rewritten the OpenIPMI SoL code so I could make it stable
    under adverse circumstances, and lots of fixes in the gensio
    code, it's stable and holds up well under duress.
* Thu Oct 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * Support for mDNS in gtlssh.
  * Some minor bug fixes.
* Tue Oct  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.7
  * bugfix release only
  * No user visible changes
* Sun Sep 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.6
  * fixed quite a number of small issues and things that weren't
    quite right.
  * No user visible changes
* Mon Aug 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.5
  * You can now set permissions on unix socket files
  * gtlssh-keygen was extended to make it easier to install new
    keys and transfer them to other systems on a key update.
    Basically, you can generate a new key then issue a command to
    copy them to other systems using the old key.
  * gtlsshd was fairly broken handling passwords if you didn't get
    the first one right. I don't use passwords very much, and I
    haven't figured out a way to automate tests on it. But it
    should work ok now.
  * Fix some minor bugs and a possible (low probability) crash in
    stdio.
  * Add some tcpd capability for setting th ename per-gensio.
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.4
  * telnet - There were some more negotiation issues.
  * serialdev - Fix issues with slow closes. A close could hang
    for a long time with pending write data, avoid this.
  * conacc - Added some extensions to make it more useful,
    general, and easy to test.
  * pty - Added the ability to create an unattached pty so another
    program can attach to it.
* Sun Jul 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.3
  * No major bug fixes or anything of that nature, some little
    things.
  The only bug that might be significant is with the pty gensio:
  it can close it's file descripter twice in some cases.
  New gensios:
  * perf - This is a fairly unusual gensio, but I created it so I
    could do performance measurements. It's fairly primitive, and I
    didn't uncover any performance issues in the gensio library
    itself, but I was useful to see how different buffer sizes
    affected performance. It does show that the Linux SCTP stack
    has some issues.
  * conacc - Another somewhat unusual gensio. This is a gensio
    accepter that takes a normal gensio string as a child. When
    started, it opens the gensio and when the open complete it
    reports a new gensio on the accepter. This has some
    interesting uses; see the docs for details.
  * Added missing man pages on the sergensio functions.
* Sun Jul 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.2
  * lots of little corner cases and race conditions are fixed and
    a few minor enhancements. If you are using in a multithreaded
    application, or using UDP, the relpkt, or the mux gensios,
    you should certainly upgrade.
  * One minor semantic change. UDP sockets are now opened without
    SO_REUSEADDR set. The UDP tests were occasionally failing,
    and it turned out that the two parts of the tests would
    sometimes get the same port, with predictable results.
- Update to version 2.1.1
  * fixes a build issue on newer gccs, a doubly-defined variable
    that I don't know how didn't cause an issue before. I've also
    been enhancing the tests a bit, and that shook out a few
    memory leaks that are also fixed.
* Sun Jun  7 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon
* Sat May 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.5
  * Fix some license issues
- Update to version 2.0.4
  * ser2net will now retry accepters and connect back connectors
    if they fail to come up or get an error.
* Tue Apr 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.3
  * Add a control to allow stdio's stdin to be closed without
    closing the gensio. This will let you write some data and then
    cause the program to see EOF on stdin, but won't affect stdout
    or stderr from the program.
  * Add a config option to not install the man pages.
* Wed Apr 22 2020 Martin Hauke <mardnh@gmx.de>
- Clarify license
* Sun Apr 19 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.0.2
